==> zent-10.0.13-beta.0.tgz: package/es/pagination/MiniPagination.js <==
import { __assign, __extends } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames';
import MiniPageList from './components/list/MiniPageList';
import layoutMini from './layout/mini';
import BasePagination from './impl/BasePagination';
var MiniPagination = (function (_super) {
    __extends(MiniPagination, _super);
    function MiniPagination() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MiniPagination.prototype, "name", {
        get: function () {
            return 'mini';
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MiniPagination.prototype, "layoutFn", {
        get: function () {
            return layoutMini;
        },
        enumerable: false,
        configurable: true
    });
    MiniPagination.prototype.render = function () {
        var _a = this.props, current = _a.current, buttonBordered = _a.buttonBordered, className = _a.className, lastPageHelp = _a.lastPageHelp;
        var layout = this.getLayout(this.props);
        return (_jsx("div", __assign({ className: cx("zent-pagination zent-pagination--" + this.name, className), "data-zv": 'v10.0.13-beta.0' }, { children: _jsx(MiniPageList, { layout: layout, current: current, onPageChange: this.onPageChange, buttonBordered: buttonBordered, lastPageHelp: lastPageHelp }, void 0) }), void 0));
    };
    MiniPagination.defaultProps = {
        current: 1,
        pageSize: 10,
        buttonBordered: false,
    };
    return MiniPagination;
}(BasePagination));
export { MiniPagination };
export default MiniPagination;

==> zent-10.0.17-beta.0.tgz: package/es/pagination/MiniPagination.js <==
import { __assign, __extends } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames';
import MiniPageList from './components/list/MiniPageList';
import layoutMini from './layout/mini';
import BasePagination from './impl/BasePagination';
var MiniPagination = (function (_super) {
    __extends(MiniPagination, _super);
    function MiniPagination() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MiniPagination.prototype, "name", {
        get: function () {
            return 'mini';
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MiniPagination.prototype, "layoutFn", {
        get: function () {
            return layoutMini;
        },
        enumerable: false,
        configurable: true
    });
    MiniPagination.prototype.render = function () {
        var _a = this.props, current = _a.current, buttonBordered = _a.buttonBordered, className = _a.className, lastPageHelp = _a.lastPageHelp;
        var layout = this.getLayout(this.props);
        return (_jsx("div", __assign({ className: cx("zent-pagination zent-pagination--" + this.name, className), "data-zv": '10.0.11-beta.0' }, { children: _jsx(MiniPageList, { layout: layout, current: current, onPageChange: this.onPageChange, buttonBordered: buttonBordered, lastPageHelp: lastPageHelp }, void 0) }), void 0));
    };
    MiniPagination.defaultProps = {
        current: 1,
        pageSize: 10,
        buttonBordered: false,
    };
    return MiniPagination;
}(BasePagination));
export { MiniPagination };
export default MiniPagination;
